<?php

namespace EventPortal\Domain\Component;

use Illuminate\Support\Str;

abstract class Component
{
    /** @var string */
    public $name;

    /** @var string */
    public $label;

    public function __construct(string $label)
    {
        $this->label = $label;
        $this->name = Str::slug($label, '_');
    }

    public static function make(string $label): self
    {
        return new static($label);
    }

    public function label(string $label): self
    {
        $this->label = $label;

        return $this;
    }

    /**
     * @param mixed $value
     * @return mixed|$this
     */
    public function when($value, callable $callback, ?callable $default = null)
    {
        if ($value) {
            return $callback($this, $value) ?: $this;
        }

        if ($default) {
            return $default($this, $value) ?: $this;
        }

        return $this;
    }
}
