<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Models\Form;
use EventPortal\Domain\Response\Models\Response;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EventEditTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function can_edit_event()
    {
        $event = factory(Event::class)->create();

        $form = factory(Form::class)
            ->create([
                'formable_id' => $event->id,
                'formable_type' => get_class($event),
            ]);

        $section = factory(Field::class)
            ->states('Section')
            ->create([
                'label' => 'Key details',
                'name' => 'key_details',
                'form_id' => $form->id,
            ]);

        $fieldA = factory(Field::class)
            ->states('TextInput')
            ->create([
                'label' => 'Event name',
                'name' => 'event_name',
                'form_id' => $form->id,
                'section_id' => $section->id,
            ]);

        $fieldB = factory(Field::class)
            ->states('Select')
            ->create([
                'label' => 'Event type',
                'name' => 'event_type',
                'form_id' => $form->id,
                'section_id' => $section->id,
                'data' => [
                    'options' => [
                        ['label' => 'Seminar', 'value' => 'seminar'],
                        ['label' => 'Single', 'value' => 'single'],
                    ],
                ],
            ]);

        factory(Response::class)
            ->create([
                'form_id' => $form->id,
                'field_id' => $fieldA->id,
                'value' => 'Hello World!',
            ]);

        factory(Response::class)
            ->create([
                'form_id' => $form->id,
                'field_id' => $fieldB->id,
                'value' => ['label' => 'Single', 'value' => 'single'],
            ]);

        $this->assertMatchesJsonSnapshot(
            $this->get(route('admin.event.edit', $event->id))->props()
        );
    }
}
