<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Models\Form;
use EventPortal\Domain\Response\Models\Response;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EventIndexTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function shows_index()
    {
        $event = factory(Event::class)->create();

        $form = factory(Form::class)
            ->create([
                'formable_id' => $event->id,
                'formable_type' => get_class($event),
            ]);

        $section = factory(Field::class)
            ->states('Section')
            ->create([
                'label' => 'Key details',
                'name' => 'key_details',
                'form_id' => $form->id,
            ]);

        $field = factory(Field::class)
            ->states('TextInput')
            ->create([
                'label' => 'Event name',
                'name' => 'event_name',
                'form_id' => $form->id,
                'section_id' => $section->id,
            ]);

        factory(Response::class)
            ->create([
                'form_id' => $form->id,
                'field_id' => $field->id,
                'value' => 'Hello World!',
            ]);

        $this->assertMatchesJsonSnapshot($this->get(route('admin.event.index'))->props());
    }
}
