<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Models\Form;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class FieldTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function can_scope_for_model()
    {
        $formA = factory(Form::class)->state('event')->create();
        $fieldA = factory(Field::class)->create(['form_id' => $formA->id]);

        $formB = factory(Form::class)->state('event')->create();
        $fieldB = factory(Field::class)->create(['form_id' => $formB->id]);

        $fields = Field::forModel($formA->formable)->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldA, $fields);
        $this->assertNotContainsModel($fieldB, $fields);
    }

    /** @test **/
    public function can_scope_for_form()
    {
        $fieldA = factory(Field::class)->create();
        $fieldB = factory(Field::class)->create();

        $fields = Field::forForm($fieldA->form)->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldA, $fields);
        $this->assertNotContainsModel($fieldB, $fields);
    }

    /** @test **/
    public function can_scope_to_only_sections()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create();

        $fields = Field::onlySections()->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldB, $fields);
        $this->assertNotContainsModel($fieldA, $fields);
    }

    /** @test **/
    public function can_scope_to_only_children()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create();

        $fields = Field::onlyChildren()->get();

        $this->assertCount(1, $fields);
        $this->assertContainsModel($fieldA, $fields);
        $this->assertNotContainsModel($fieldB, $fields);
    }

    /** @test **/
    public function can_determine_if_it_is_a_child()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create(['section_id' => null]);

        $this->assertTrue($fieldA->isChild());
        $this->assertFalse($fieldB->isChild());
    }

    /** @test **/
    public function can_determine_if_it_is_a_parent()
    {
        $fieldA = factory(Field::class)->create(['section_id' => 1]);
        $fieldB = factory(Field::class)->create(['section_id' => null]);

        $this->assertFalse($fieldA->isParent());
        $this->assertTrue($fieldB->isParent());
    }
}
